aboutsummaryrefslogtreecommitdiff
path: root/src/common/linux/dump_symbols.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/common/linux/dump_symbols.h')
-rw-r--r--src/common/linux/dump_symbols.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/common/linux/dump_symbols.h b/src/common/linux/dump_symbols.h
index e1a930ac..3749d1f6 100644
--- a/src/common/linux/dump_symbols.h
+++ b/src/common/linux/dump_symbols.h
@@ -35,19 +35,19 @@
#ifndef COMMON_LINUX_DUMP_SYMBOLS_H__
#define COMMON_LINUX_DUMP_SYMBOLS_H__
-#include <stdio.h>
-
+#include <iostream>
#include <string>
namespace google_breakpad {
// Find all the debugging information in OBJ_FILE, an ELF executable
// or shared library, and write it to SYM_FILE in the Breakpad symbol
// file format.
// If OBJ_FILE has been stripped but contains a .gnu_debuglink section,
// then look for the debug file in DEBUG_DIR.
bool WriteSymbolFile(const std::string &obj_file,
- const std::string &debug_dir, FILE *sym_file);
+ const std::string &debug_dir,
+ std::ostream &sym_stream);
} // namespace google_breakpad
@@ -35,19 +35,19 @@
namespace google_breakpad {
// Find all the debugging information in OBJ_FILE, an ELF executable
-// or shared library, and write it to SYM_FILE in the Breakpad symbol
+// or shared library, and write it to SYM_STREAM in the Breakpad symbol
// file format.
// If OBJ_FILE has been stripped but contains a .gnu_debuglink section,